@@ -2,6 +2,7 @@ from .aggregates import aggregated
 from .batch import batch_fetch, with_backrefs
 from .decorators import generates
 from .exceptions import ImproperlyConfigured
+from .expression_parser import ExpressionParser
 from .functions import (
     create_database,
     create_mock_engine,
@@ -59,7 +60,7 @@ from .types import (
 )
 
 
-__version__ = '0.25.3'
+__version__ = '0.25.4'
 
 
 __all__ = (
@@ -99,6 +100,7 @@ __all__ = (
     DateRangeType,
     DateTimeRangeType,
     EmailType,
+    ExpressionParser,
     ImproperlyConfigured,
     InstrumentedList,
     IntRangeType,
